@@ -14,9 +14,11 @@ use {
 pub(crate) struct Config {
   pub(crate) alias_style: AliasStyle,
   pub(crate) allow_missing: bool,
+  pub(crate) ceiling: Option<PathBuf>,
   pub(crate) check: bool,
   pub(crate) color: Color,
   pub(crate) command_color: Option<ansi_term::Color>,
+  pub(crate) cygpath: PathBuf,
   pub(crate) dotenv_filename: Option<String>,
   pub(crate) dotenv_path: Option<PathBuf>,
   pub(crate) dry_run: bool,
@@ -36,6 +38,7 @@ pub(crate) struct Config {
   pub(crate) shell_args: Option<Vec<String>>,
   pub(crate) shell_command: bool,
   pub(crate) subcommand: Subcommand,
+  pub(crate) tempdir: Option<PathBuf>,
   pub(crate) timestamp: bool,
   pub(crate) timestamp_format: String,
   pub(crate) unsorted: bool,
@@ -90,11 +93,13 @@ mod arg {
   pub(crate) const ALIAS_STYLE: &str = "ALIAS_STYLE";
   pub(crate) const ALLOW_MISSING: &str = "ALLOW-MISSING";
   pub(crate) const ARGUMENTS: &str = "ARGUMENTS";
+  pub(crate) const CEILING: &str = "CEILING";
   pub(crate) const CHECK: &str = "CHECK";
   pub(crate) const CHOOSER: &str = "CHOOSER";
   pub(crate) const CLEAR_SHELL_ARGS: &str = "CLEAR-SHELL-ARGS";
   pub(crate) const COLOR: &str = "COLOR";
   pub(crate) const COMMAND_COLOR: &str = "COMMAND-COLOR";
+  pub(crate) const CYGPATH: &str = "CYGPATH";
   pub(crate) const DOTENV_FILENAME: &str = "DOTENV-FILENAME";
   pub(crate) const DOTENV_PATH: &str = "DOTENV-PATH";
   pub(crate) const DRY_RUN: &str = "DRY-RUN";
@@ -116,6 +121,7 @@ mod arg {
   pub(crate) const SHELL: &str = "SHELL";
   pub(crate) const SHELL_ARG: &str = "SHELL-ARG";
   pub(crate) const SHELL_COMMAND: &str = "SHELL-COMMAND";
+  pub(crate) const TEMPDIR: &str = "TEMPDIR";
   pub(crate) const TIMESTAMP: &str = "TIMESTAMP";
   pub(crate) const TIMESTAMP_FORMAT: &str = "TIMESTAMP-FORMAT";
   pub(crate) const UNSORTED: &str = "UNSORTED";
@@ -157,6 +163,14 @@ impl Config {
           .help("Set list command alias display style")
           .conflicts_with(arg::NO_ALIASES),
       )
+      .arg(
+        Arg::new(arg::CEILING)
+          .long("ceiling")
+          .env("JUST_CEILING")
+          .action(ArgAction::Set)
+          .value_parser(value_parser!(PathBuf))
+          .help("Do not ascend above <CEILING> directory when searching for a justfile."),
+      )
       .arg(
         Arg::new(arg::CHECK)
           .long("check")
@@ -198,6 +212,15 @@ impl Config {
           .value_parser(clap::value_parser!(CommandColor))
           .help("Echo recipe lines in <COMMAND-COLOR>"),
       )
+      .arg(
+        Arg::new(arg::CYGPATH)
+          .long("cygpath")
+          .env("JUST_CYGPATH")
+          .action(ArgAction::Set)
+          .value_parser(value_parser!(PathBuf))
+          .default_value("cygpath")
+          .help("Use binary at <CYGPATH> to convert between unix and Windows paths."),
+      )
       .arg(
         Arg::new(arg::DOTENV_FILENAME)
           .long("dotenv-filename")
@@ -373,6 +396,14 @@ impl Config {
           .action(ArgAction::SetTrue)
           .help("Invoke <COMMAND> with the shell used to run recipe lines and backticks"),
       )
+      .arg(
+        Arg::new(arg::TEMPDIR)
+          .action(ArgAction::Set)
+          .env("JUST_TEMPDIR")
+          .long("tempdir")
+          .value_parser(value_parser!(PathBuf))
+          .help("Save temporary files to <TEMPDIR>."),
+      )
       .arg(
         Arg::new(arg::TIMESTAMP)
           .action(ArgAction::SetTrue)
@@ -756,12 +787,14 @@ impl Config {
         .unwrap()
         .clone(),
       allow_missing: matches.get_flag(arg::ALLOW_MISSING),
+      ceiling: matches.get_one::<PathBuf>(arg::CEILING).cloned(),
       check: matches.get_flag(arg::CHECK),
       color: (*matches.get_one::<UseColor>(arg::COLOR).unwrap()).into(),
       command_color: matches
         .get_one::<CommandColor>(arg::COMMAND_COLOR)
         .copied()
         .map(CommandColor::into),
+      cygpath: matches.get_one::<PathBuf>(arg::CYGPATH).unwrap().clone(),
       dotenv_filename: matches
         .get_one::<String>(arg::DOTENV_FILENAME)
         .map(Into::into),
@@ -792,6 +825,7 @@ impl Config {
       },
       shell_command: matches.get_flag(arg::SHELL_COMMAND),
       subcommand,
+      tempdir: matches.get_one::<PathBuf>(arg::TEMPDIR).map(Into::into),
       timestamp: matches.get_flag(arg::TIMESTAMP),
       timestamp_format: matches
         .get_one::<String>(arg::TIMESTAMP_FORMAT)
