@@ -601,6 +601,65 @@ fn submodule_shebang_recipes_run_in_submodule_directory() {
     .run();
 }
 
+#[test]
+fn cross_module_dependency_runs_in_submodule_directory() {
+  Test::new()
+    .write("foo/bar", "BAR")
+    .write("foo/mod.just", "foo:\n @cat bar")
+    .justfile(
+      "
+        mod foo
+
+        main: foo::foo
+      ",
+    )
+    .arg("main")
+    .stdout("BAR")
+    .run();
+}
+
+#[test]
+fn cross_module_dependency_with_no_cd_runs_in_invocation_directory() {
+  Test::new()
+    .write("root_file", "ROOT")
+    .write(
+      "foo/mod.just",
+      "
+[no-cd]
+foo:
+  @cat root_file
+      ",
+    )
+    .justfile(
+      "
+        mod foo
+
+        main: foo::foo
+      ",
+    )
+    .arg("main")
+    .stdout("ROOT")
+    .run();
+}
+
+#[test]
+fn nested_cross_module_dependency_runs_in_correct_directory() {
+  Test::new()
+    .write("outer/inner/file", "NESTED")
+    .write("outer/inner/mod.just", "task:\n @cat file")
+    .write("outer/mod.just", "mod inner")
+    .justfile(
+      "
+        mod outer
+
+        main: outer::inner::task
+      ",
+    )
+    .arg("main")
+    .stdout("NESTED")
+    .run();
+}
+
 #[cfg(not(windows))]
 #[test]
 fn module_paths_beginning_with_tilde_are_expanded_to_homdir() {
@@ -987,7 +1046,7 @@ fn empty_doc_attribute_on_module() {
   Test::new()
     .write("foo.just", "")
     .justfile(
-      r"
+      "
         # Suppressed comment
         [doc]
         mod foo
@@ -998,3 +1057,74 @@ fn empty_doc_attribute_on_module() {
     .stdout("Available recipes:\n    foo ...\n")
     .run();
 }
+
+#[test]
+fn overrides_work_when_submodule_is_present() {
+  Test::new()
+    .write("bar.just", "")
+    .justfile(
+      "
+        mod bar
+
+        x := 'a'
+
+        foo:
+          @echo {{ x }}
+      ",
+    )
+    .test_round_trip(false)
+    .arg("x=b")
+    .stdout("b\n")
+    .run();
+}
+
+#[test]
+fn exported_variables_are_available_in_submodules() {
+  Test::new()
+    .write("foo.just", "bar:\n @echo $x")
+    .justfile(
+      "
+        mod foo
+
+        export x := 'a'
+      ",
+    )
+    .test_round_trip(false)
+    .arg("foo::bar")
+    .stdout("a\n")
+    .run();
+}
+
+#[test]
+fn exported_variables_can_be_unexported_in_submodules() {
+  Test::new()
+    .write("foo.just", "unexport x\nbar:\n @echo ${x:-default}")
+    .justfile(
+      "
+        mod foo
+
+        export x := 'a'
+      ",
+    )
+    .test_round_trip(false)
+    .arg("foo::bar")
+    .stdout("default\n")
+    .run();
+}
+
+#[test]
+fn exported_variables_can_be_overridden_in_submodules() {
+  Test::new()
+    .write("foo.just", "export x := 'b'\nbar:\n @echo $x")
+    .justfile(
+      "
+        mod foo
+
+        export x := 'a'
+      ",
+    )
+    .test_round_trip(false)
+    .arg("foo::bar")
+    .stdout("b\n")
+    .run();
+}
